@@ -210,11 +210,11 @@ class Jenkins(
                 scope: constructs.Construct,
                 id: builtins.str,
                 *,
-                base_plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
+                base_plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[str, typing.Any]]]] = None,
                 disable_csrf_protection: typing.Optional[builtins.bool] = None,
                 metadata: typing.Optional[typing.Union[cdk8s.ApiObjectMetadata, typing.Dict[str, typing.Any]]] = None,
-                plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
-                seed_jobs: typing.Optional[typing.Sequence[typing.Union["SeedJob", typing.Dict[str, typing.Any]]]] = None,
+                plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[str, typing.Any]]]] = None,
+                seed_jobs: typing.Optional[typing.Sequence[typing.Union[SeedJob, typing.Dict[str, typing.Any]]]] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -237,7 +237,7 @@ class Jenkins(
         :param base_plugins: List of base plugins.
         '''
         if __debug__:
-            def stub(*base_plugins: "Plugin") -> None:
+            def stub(*base_plugins: Plugin) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
             check_type(argname="argument base_plugins", value=base_plugins, expected_type=typing.Tuple[type_hints["base_plugins"], ...]) # pyright: ignore [reportGeneralTypeIssues]
@@ -250,7 +250,7 @@ class Jenkins(
         :param plugins: List of custom plugins.
         '''
         if __debug__:
-            def stub(*plugins: "Plugin") -> None:
+            def stub(*plugins: Plugin) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
             check_type(argname="argument plugins", value=plugins, expected_type=typing.Tuple[type_hints["plugins"], ...]) # pyright: ignore [reportGeneralTypeIssues]
@@ -263,7 +263,7 @@ class Jenkins(
         :param seed_jobs: List of seed jobs.
         '''
         if __debug__:
-            def stub(*seed_jobs: "SeedJob") -> None:
+            def stub(*seed_jobs: SeedJob) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
             check_type(argname="argument seed_jobs", value=seed_jobs, expected_type=typing.Tuple[type_hints["seed_jobs"], ...]) # pyright: ignore [reportGeneralTypeIssues]
@@ -304,11 +304,11 @@ class JenkinsProps:
         if __debug__:
             def stub(
                 *,
-                base_plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
+                base_plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[str, typing.Any]]]] = None,
                 disable_csrf_protection: typing.Optional[builtins.bool] = None,
                 metadata: typing.Optional[typing.Union[cdk8s.ApiObjectMetadata, typing.Dict[str, typing.Any]]] = None,
-                plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
-                seed_jobs: typing.Optional[typing.Sequence[typing.Union["SeedJob", typing.Dict[str, typing.Any]]]] = None,
+                plugins: typing.Optional[typing.Sequence[typing.Union[Plugin, typing.Dict[str, typing.Any]]]] = None,
+                seed_jobs: typing.Optional[typing.Sequence[typing.Union[SeedJob, typing.Dict[str, typing.Any]]]] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
